{ TEditSeek v1.0
  Author: Craig Manley, 20 October 1998. craig@skybound.demon.nl
  Description:
    Derived from TEdit. Useful for locating records in a table
    when the user has to type in a search string. An extra OnSeek
    event is used for this. OnSeek occurs DelayMs milliseconds
    later than the last OnChange event.
    This is freeware. If you find bugs or improve on it please email me.
  New properties:
    Active: boolean -> Set to true if component cause OnSeek events.
    DelayMs: unsigned integer -> The delay in milliseconds between
             the last OnChange event and the following single OnSeek event.
  New events:
    OnSeek: Occurs once after possible multiple OnChange events.
            It occurs DelayMs later than the last OnChange event.

}

unit EditSeek;

interface

uses
  Windows, Messages, Classes, StdCtrls;

type
  TEditSeek = class(TEdit)
  private
    FActive: boolean;
    FTimeOut: UINT;
    FTimerID: UINT;
    FOnSeek: TNotifyEvent;
  protected
    procedure SetActive(b: boolean);
    procedure Change; override;
  public
    constructor Create(AOwner: TComponent); override;
    destructor Destroy; override;
    procedure WndProc(var Message : TMessage);override;
  published
    property Active: boolean read FActive write SetActive;
    property DelayMs: UINT read FTimeOut write FTimeOut;
    property OnSeek: TNotifyEvent read FOnSeek write FOnSeek;
  end;

procedure Register;

implementation

procedure Register;
begin
  RegisterComponents('Freeware', [TEditSeek]);
end;

constructor TEditSeek.Create(AOwner: TComponent);
begin
  inherited;
  FActive := False;
  FOnSeek := nil;
  FTimeOut := 500;
  FTimerID := 0;
end;

destructor TEditSeek.Destroy;
begin
  if FTimerID > 0 then
    KillTimer(self.Handle, FTimerID);
  inherited;
end;

procedure TEditSeek.SetActive(b: boolean);
begin
  if FActive and (FTimerID > 0) then
    KillTimer(self.Handle, FTimerID);
  FActive := b;
end;

procedure TEditSeek.Change;
begin
  inherited Change;
  if FActive then
  begin
    if FTimerID > 0 then
      KillTimer(self.Handle, FTimerID);
    FTimerID := SetTimer(self.Handle, self.Handle, FTimeOut, nil);
  end;
end;

procedure TEditSeek.WndProc(var Message: TMessage);
begin
  inherited;
  if FActive and (Message.Msg = WM_TIMER) and (Message.WParam = FTimerID) then
  begin
    if assigned(FOnSeek) then
      FOnSeek(self);
    FTimerID := 0;
    Message.Result := 0;
  end
end;


end.
